From 39260208613fe1d8613cd90d6766859fb6104f56 Mon Sep 17 00:00:00 2001
From: Amul Sul <amul.sul@enterprisedb.com>
Date: Thu, 29 Apr 2021 01:00:06 -0400
Subject: [PATCH 1/2] Hide internal temp schema name

---
 contrib/postgres_fdw/postgres_fdw.c | 4 +++-
 src/backend/commands/explain.c      | 5 +++--
 2 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/contrib/postgres_fdw/postgres_fdw.c b/contrib/postgres_fdw/postgres_fdw.c
index e201b5404e6..80cd4334b1e 100644
--- a/contrib/postgres_fdw/postgres_fdw.c
+++ b/contrib/postgres_fdw/postgres_fdw.c
@@ -2794,9 +2794,11 @@ postgresExplainForeignScan(ForeignScanState *node, ExplainState *es)
 				relname = get_rel_name(rte->relid);
 				if (es->verbose)
 				{
+					Oid         namespaceOid;
 					char	   *namespace;
 
-					namespace = get_namespace_name(get_rel_namespace(rte->relid));
+					namespaceOid = get_rel_namespace(rte->relid);
+					namespace = get_namespace_name_or_temp(namespaceOid);
 					appendStringInfo(relations, "%s.%s",
 									 quote_identifier(namespace),
 									 quote_identifier(relname));
diff --git a/src/backend/commands/explain.c b/src/backend/commands/explain.c
index 3d5198e2345..16f2bf04026 100644
--- a/src/backend/commands/explain.c
+++ b/src/backend/commands/explain.c
@@ -3747,7 +3747,8 @@ ExplainTargetRel(Plan *plan, Index rti, ExplainState *es)
 			Assert(rte->rtekind == RTE_RELATION);
 			objectname = get_rel_name(rte->relid);
 			if (es->verbose)
-				namespace = get_namespace_name(get_rel_namespace(rte->relid));
+				namespace =
+					get_namespace_name_or_temp(get_rel_namespace(rte->relid));
 			objecttag = "Relation Name";
 			break;
 		case T_FunctionScan:
@@ -3775,7 +3776,7 @@ ExplainTargetRel(Plan *plan, Index rti, ExplainState *es)
 						objectname = get_func_name(funcid);
 						if (es->verbose)
 							namespace =
-								get_namespace_name(get_func_namespace(funcid));
+								get_namespace_name_or_temp(get_func_namespace(funcid));
 					}
 				}
 				objecttag = "Function Name";
-- 
2.18.0

